@@ -12,9 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import argparse
-
-import aiohttp.web
-
 import logging
 
 logger = logging.getLogger()
@@ -31,11 +28,13 @@ parser.add_argument("--port", type=int, default=5000)
 parser.add_argument("--host", type=str, default="127.0.0.1")
 
 
-if __name__ == "__main__":
+def main():
     from magicproxy import proxy, async_proxy
 
     args = parser.parse_args()
-    if args.run_async:
-        aiohttp.web.run_app(async_proxy.build_app([]), host=args.host, port=args.port)
-    else:
-        proxy.run_app(host=args.host, port=args.port)
+    module = async_proxy if args.run_async else proxy
+    module.run_app(host=args.host, port=args.port)
+
+
+if __name__ == "__main__":
+    main()
